# ListResourceRolesResponse

Response object for listing ResourceRoles.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_roles** | [**list[ResourceRole]**](ResourceRole.md) | The matching ResourceRole objects. | 
**limit** | **int** | Limit on the number of rows in the response. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


